package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaLiveActivity;
import com.huiju.estateagents.service.ITaLiveActivityService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2020-02-20
 */
@RestController
@RequestMapping("/api")
public class TaLiveActivityController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaLiveActivityController.class);

    @Autowired
    public ITaLiveActivityService iTaLiveActivityService;

    /**
     * 分页查询列表
     *
     * @param pageNum
     * @param pageSize
     * @param liveActivityTitle 直播活动标题
     * @param cityId            所属城市
     * @param buildingId        所属楼盘
     * @param liveDetailType    详情类型 0是模板，1是自定义
     * @param status            状态
     * @param request
     * @return
     */
    @RequestMapping(value = "/admin/taLiveActivity", method = RequestMethod.GET)
    public ResponseBean taLiveActivityList(@RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                           @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                                           String liveActivityTitle, String cityId, String buildingId, Integer status,
                                           HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            IPage<TaLiveActivity> result = iTaLiveActivityService.listLiveActivityByCondition(pageNum, pageSize, getOrgId(request),
                    liveActivityTitle, cityId, buildingId, status);
            responseBean.addSuccess(result);

        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taLiveActivityList -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     *
     * @param taLiveActivity 实体对象
     * @return
     */
    @RequestMapping(value = "/admin/taLiveActivity", method = RequestMethod.POST)
    public ResponseBean taLiveActivityAdd(@RequestBody TaLiveActivity taLiveActivity, HttpServletRequest request) {
        ResponseBean responseBean = new ResponseBean();
        try {
            Integer orgId = getOrgId(request);
            taLiveActivity.setOrgId(orgId);
            responseBean = iTaLiveActivityService.taLiveActivityAdd(taLiveActivity);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taLiveActivityAdd -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     *
     * @param id 实体ID
     */
    @ResponseBody
    @RequestMapping(value = "/taLiveActivity/{id}", method = RequestMethod.DELETE)
    public ResponseBean taLiveActivityDelete(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            TaLiveActivity taLiveActivity = new TaLiveActivity();
            taLiveActivity.setLiveActivityId(id);
            taLiveActivity.setStatus(CommConstant.STATUS_UNACCALIMED);
            taLiveActivity.setUpdateDate(LocalDateTime.now());

            if (iTaLiveActivityService.updateById(taLiveActivity)) {
                responseBean.addSuccess("success");
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taLiveActivityDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     *
     * @param id             实体ID
     * @param taLiveActivity 实体对象
     * @return
     */
    @RequestMapping(value = "/admin/taLiveActivity/{id}", method = RequestMethod.PUT)
    public ResponseBean taLiveActivityUpdate(@PathVariable Integer id,
                                             @RequestBody TaLiveActivity taLiveActivity) {
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaLiveActivityService.updateById(taLiveActivity)) {
                responseBean.addSuccess(taLiveActivity);
            } else {
                responseBean.addError("fail");
            }
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taLiveActivityUpdate -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     *
     * @param id 实体ID
     */
    @RequestMapping(value = "/admin/taLiveActivity/{id}", method = RequestMethod.GET)
    public ResponseBean taLiveActivityGet(@PathVariable Integer id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaLiveActivityService.getById(id));
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("taLiveActivityDelete -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 访问量自增
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/wx/addVisitNum", method = RequestMethod.PUT)
    public ResponseBean addVisitNum(@RequestParam("id") String id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaLiveActivityService.addVisitNum(id);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("addVisitNum -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 获取直播详情
     *
     * @param id
     * @return
     */
    @RequestMapping(value = "/wx/taLiveActivity/{id}", method = RequestMethod.GET)
    public ResponseBean getLiveActivityDetailById(@PathVariable("id") String id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaLiveActivityService.getLiveActivityDetailById(id);
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("getLiveActivityDetailById -=- {}", e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
